@@ -1,14 +1,14 @@
 class DeletableMixin:
-    '''Interface for classes that can be edited and deleted.'''
+    """Interface for classes that can be edited and deleted."""
 
     def delete(self):
-        '''Delete the object.
+        """Delete the object.
 
         Example usage:
 
-        .. code:: python
+        .. code-block:: python
 
-            bot = credentialManager.bot('name')
+            bot = credentialManager.bot("name")
 
             redditApp = bot.redditApp
             redditApp.delete()
@@ -20,6 +20,7 @@ class DeletableMixin:
             databaseCredential.delete()
 
             userVerification = cre
-        '''
-        self._credmgr.delete(f'{self._path}/{self.id}')
-        del self
\ No newline at end of file
+
+        """
+        self._credmgr.delete(f"{self._path}/{self.id}")
+        del self
